==> haskell-cryptohash-conduit-0.1.1-240-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-CvsxHxFyRZDJC6pIyENzqy
key: cryptohash-conduit-0.1.1-CvsxHxFyRZDJC6pIyENzqy
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: f37c3099c5d64f48e58d5fbb0af9052a
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-CvsxHxFyRZDJC6pIyENzqy
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-4fX2vDGzfwnKn8FIoLwwSG
    conduit-extra-1.3.0-43TP7AjhTPVAtsUVRfOjgA
    cryptohash-0.11.9-77MP0yrSXtp3wxv1jEwRwy
    resourcet-1.2.2-1GcRGMcYBbwIukAqEHFrag transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-242-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-3ZsPcBmJLor6nYQoWWVCym
key: cryptohash-conduit-0.1.1-3ZsPcBmJLor6nYQoWWVCym
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: 933e42a7cfaa4e325d56f7db45fdb72a
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-3ZsPcBmJLor6nYQoWWVCym
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-BmabwSZESuG6iKDxLo0IET
    conduit-extra-1.3.0-Eiv0jewZlXw2l4aTFErB0V
    cryptohash-0.11.9-77MP0yrSXtp3wxv1jEwRwy
    resourcet-1.2.2-1GcRGMcYBbwIukAqEHFrag transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
